<?php

namespace Drupal\horizontal_scrolling_announcement\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Block\BlockPluginInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'horizontal_scrolling_announcement' Block
 *
 * @Block(
 * id = "horizontal_scrolling_announcement",
 * admin_label = @Translation("Horizontal scrolling announcement"),
 * )
 */
class horizontal_scrolling_announcement_block extends BlockBase implements BlockPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function build() {
  	$config = $this->getConfiguration();

    if (!empty($config['hsa_scrollamount'])) {
      $hsa_scrollamount = $config['hsa_scrollamount'];
    }
    else {
      $hsa_scrollamount = "";
    }
	
	if (!empty($config['hsa_scrolldelay'])) {
      $hsa_scrolldelay = $config['hsa_scrolldelay'];
    }
    else {
      $hsa_scrolldelay = "";
    }
	
	if (!empty($config['hsa_direction'])) {
      $hsa_direction = $config['hsa_direction'];
    }
    else {
      $hsa_direction = "";
    }
	
	if (!empty($config['hsa_style'])) {
      $hsa_style = $config['hsa_style'];
    }
    else {
      $hsa_style = "";
    }
	
	if (!empty($config['hsa_announcement'])) {
      $hsa_announcement = $config['hsa_announcement'];
    }
    else {
      $hsa_announcement = "";
    }
	
	$output = array();
	$output[]['#cache']['max-age'] = 0; // No cache
	$values = [
		'hsa_scrollamount' => $hsa_scrollamount,
		'hsa_scrolldelay' => $hsa_scrolldelay,
		'hsa_direction' => $hsa_direction,
		'hsa_style' => $hsa_style,
		'hsa_announcement' => $hsa_announcement,
    ];
	
	$markup = $this->hsaBlock($values);
	$output[] = ['#markup' => t($markup) , '#allowed_tags' => ['span', 'div', 'a', 'marquee', 'img'],];

	return $output;
  }
  
  /**
   * @param array $values
   * @return string
   */
  private function hsaBlock(array $values) {
    $request = \Drupal::request();
	
	$hsa_scrollamount = $values['hsa_scrollamount'];
	$hsa_scrolldelay = $values['hsa_scrolldelay'];
	$hsa_direction = $values['hsa_direction'];
	$hsa_style = $values['hsa_style'];
	$hsa_announcement = $values['hsa_announcement'];
	
	if(!is_numeric($hsa_scrollamount)) {
		$hsa_scrollamount = 2;
	}
	
	if(!is_numeric($hsa_scrolldelay)) {
		$hsa_scrolldelay = 5;
	}
	
	if($hsa_direction <> "left" && $hsa_direction <> "right" ) {
		$hsa_direction = "left";
	}
	
	$target = "_self";
	$cnt = 0;
	$marquee = "";
	$hsa = "";
	
	$hsa_announcement_arry = explode("\n", $hsa_announcement);
	$hsa_announcement_arry = array_filter($hsa_announcement_arry, 'trim'); // remove any extra \r characters left behind
	foreach ($hsa_announcement_arry as $hsa_announcement) 
	{
		$hsa_announcement = preg_replace( "/\r|\n/", "", $hsa_announcement); // remove line break from right
		
		if (strpos($hsa_announcement,']-[') !== false) 
		{
			$hsa_announcement = explode("]-[", $hsa_announcement); // split image and link
			$announcement_txt = $hsa_announcement[0];
			$announcement_lnk = $hsa_announcement[1];
		}
		elseif (strpos($hsa_announcement,'] - [') !== false) 
		{
			$hsa_announcement = explode("] - [", $hsa_announcement); // split image and link
			$announcement_txt = $hsa_announcement[0];
			$announcement_lnk = $hsa_announcement[1];
		}
		elseif (strpos($hsa_announcement,']- [') !== false) 
		{
			$hsa_announcement = explode("]- [", $hsa_announcement); // split image and link
			$announcement_txt = $hsa_announcement[0];
			$announcement_lnk = $hsa_announcement[1];
		}
		elseif (strpos($hsa_announcement,'] -[') !== false) 
		{
			$hsa_announcement = explode("] -[", $hsa_announcement); // split image and link
			$announcement_txt = $hsa_announcement[0];
			$announcement_lnk = $hsa_announcement[1];
		}
		else
		{
			if ($hsa_announcement <> "")
			{
				$announcement_txt = $hsa_announcement;
				$announcement_lnk = "";
			}
		}
		
		$announcement_txt = ltrim($announcement_txt, '['); // remove first character from left
		$announcement_txt = rtrim($announcement_txt, ']'); // remove last character from right
		
		$announcement_lnk = ltrim($announcement_lnk, '['); // remove first character from left
		$announcement_lnk = rtrim($announcement_lnk, ']'); // remove last character from right
		
		if($announcement_lnk != "") { 
			$hsa = $hsa . "<a target='".$target."' href='".$announcement_lnk."'>"; 
		} 
		
		$hsa = $hsa . stripslashes($announcement_txt);
		
		if($announcement_lnk != "") { 
			$hsa = $hsa . "</a>"; 
		}
		
		$hsa = $hsa . "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
				
		$cnt = $cnt + 1;
	}
	
	$marquee = $marquee . "<marquee style='$hsa_style' scrollamount='$hsa_scrollamount' scrolldelay='$hsa_scrolldelay' direction='$hsa_direction' onmouseover='this.stop()' onmouseout='this.start()'>";
	$marquee = $marquee . $hsa;
	$marquee = $marquee . "</marquee>";
		
	return $marquee;
	
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $config = $this->getConfiguration();

    $form['hsa_scrollamount'] = array (
      '#type' => 'textfield',
      '#title' => $this->t('Scroll amount'),
      '#description' => $this->t('Please enter scroll amount, This will make the scroll faster. (Example: 2)'),
      '#default_value' => isset($config['hsa_scrollamount']) ? $config['hsa_scrollamount'] : '2'
    );
	
	$form['hsa_scrolldelay'] = array (
      '#type' => 'textfield',
      '#title' => $this->t('Scroll delay'),
      '#description' => $this->t('Please enter amount of delay in milliseconds. (Example: 5)'),
      '#default_value' => isset($config['hsa_scrolldelay']) ? $config['hsa_scrolldelay'] : '5'
    );
	
	$options = array(
      'left' => $this->t('scroll from right to left'),
      'right' => $this->t('scroll from left to right'),
    );
	
	$form['hsa_direction'] = array (
      '#type' => 'radios',
      '#title' => $this->t('Scroll direction'),
	  '#options' => $options,
      '#description' => $this->t('Please select your direction for announcement scrolling.'),
	  '#default_value' => $config['hsa_direction'],
    );
	
	$form['hsa_style'] = array (
      '#type' => 'textfield',
      '#title' => $this->t('CSS attribute'),
      '#description' => $this->t('Please enter your CSS attributes for style. (Example: color:#FF0000; font:Arial;)'),
      '#default_value' => isset($config['hsa_style']) ? $config['hsa_style'] : ''
    );
	
	$form['hsa_announcement'] = array (
      '#type' => 'textarea',
      '#title' => $this->t('Announcementc text'),
      '#description' => $this->t('Please enter your scrolling announcement text. One announcement per line. <br /> [Your announcement text]-[When someone clicks on the announcement, where do you want to send them] <br /> Example : [Congratulations, you just completed configure]-[http://www.gopiplus.com/]'),
      '#default_value' => isset($config['hsa_announcement']) ? $config['hsa_announcement'] : '[Congratulations, you just completed configure.]-[http://www.gopiplus.com/extensions/]'
    );

    return $form;
  }
  
   /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['hsa_scrollamount'] = $form_state->getValue('hsa_scrollamount');
	$this->configuration['hsa_scrolldelay'] = $form_state->getValue('hsa_scrolldelay');
	$this->configuration['hsa_direction'] = $form_state->getValue('hsa_direction');
	$this->configuration['hsa_style'] = $form_state->getValue('hsa_style');
	$this->configuration['hsa_announcement'] = $form_state->getValue('hsa_announcement');
  }
}